//////////////////////////////////////////////////////////////////////////
// Copyright 2005-2007 Aspose Pty Ltd. All Rights Reserved.
//
// This file is part of Aspose.Editor. The source code in this file
// is only intended as a supplement to the documentation, and is provided
// "as is", without warranty of any kind, either expressed or implied.
//////////////////////////////////////////////////////////////////////////
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.IO;
using System.Reflection;
using System.Threading;
using System.Windows.Forms;
using Aspose.Editor.Desktop;
using License=Aspose.Editor.Desktop.License;
using MenuItem=Aspose.Editor.Desktop.MenuItem;

namespace Aspose.Editor.Demo
{
    /// <summary>
    /// The main form of the Aspose.Editor.Demo application.
    /// </summary>
    public class MainForm : Form
    {
        #region Windows Form Designer generated code

        /// <summary>
        /// Required method for Designer support - do not modify
        /// the contents of this method with the code editor.
        /// </summary>
        private void InitializeComponent()
        {
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(MainForm));
			this.docEditor = new Aspose.Editor.Desktop.EditorControl();
			this.SuspendLayout();
			// 
			// docEditor
			// 
			this.docEditor.BackColor = System.Drawing.Color.FromArgb(((System.Byte)(143)), ((System.Byte)(169)), ((System.Byte)(213)));
			this.docEditor.Dock = System.Windows.Forms.DockStyle.Fill;
			this.docEditor.Document = null;
			this.docEditor.ForeColor = System.Drawing.SystemColors.Window;
			this.docEditor.IsScrollBarsVisible = true;
			this.docEditor.LayoutType = Aspose.Editor.Desktop.LayoutType.Page;
			this.docEditor.Location = new System.Drawing.Point(0, 0);
			this.docEditor.Name = "docEditor";
			this.docEditor.Origin = ((System.Drawing.PointF)(resources.GetObject("docEditor.Origin")));
			this.docEditor.Size = new System.Drawing.Size(928, 665);
			this.docEditor.TabIndex = 1;
			// 
			// MainForm
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(928, 665);
			this.Controls.Add(this.docEditor);
			this.Name = "MainForm";
			this.Text = "Microsoft Visual Studio 2005";
			this.Closing += new System.ComponentModel.CancelEventHandler(this.MainForm_Closing);
			this.ResumeLayout(false);

		}

        #endregion

        /// <summary>
        /// The main entry point for the application.
        /// </summary>
        [STAThread]
        private static void Main()
        {
            Application.EnableVisualStyles();
            Application.DoEvents();
            Application.Run(new MainForm());
        }


        /// <summary>
        /// Initializes new instance of the <see cref="MainForm"/> class.
        /// </summary>
        public MainForm()
        {
            // Required for Windows Form Designer support
            InitializeComponent();

            // Build license path
            string licenseFileName = Path.Combine(Path.GetDirectoryName(
                                        Application.ExecutablePath), @"Aspose.Editor.lic");

            if ( File.Exists(licenseFileName) )
            {
                // === THIS IS HOW TO APPLY A LICENSE FOR ASPOSE.EDITOR
                // The above check is only for demo to work both with and without a license.
                //
                // If you don't specify a license, Aspose.Editor works in evaluation mode.
                //
                // In your code you can just put the license file in the same folder as your
                // application or embed it into your executable as a resource and specify only
                // license file name without path.
                Aspose.Editor.Desktop.License license = new Aspose.Editor.Desktop.License();
                license.SetLicense(licenseFileName);
            }

            // Install spell checkers
            InstallSpellChecker();

            // Create new command "AppExit" and add it to the menu
            CreateAppExitCommand();

            // Create new command "ReadOnly" and add it to the menu
            CreateReadOnlyCommand();

            // Wire thread exception and idle events
            Application.ThreadException += new ThreadExceptionEventHandler(Application_ThreadException);
            Application.Idle += new EventHandler(Application_Idle);

            // Show splash screen
            AboutDialog dlg = new AboutDialog();
            dlg.ShowDialog();

            // Load default document
            docEditor.Document = new Document(
                Path.Combine(Path.GetDirectoryName(Application.ExecutablePath), @"..\Welcome.doc"));
        }


        /// <summary>
        /// This method attaches spell checker adapter to the editor. We dont want to link this demo
        /// with third-party controls thus we have to dynamically load adapter assembly and fail
        /// silently if there is no keyoti spell checker installed.
        /// </summary>
        private void InstallSpellChecker()
        {
            try
            {
                KeyotiRapidSpellAdapter.Install(docEditor);
            }
            catch
            {
                Debug.WriteLine("Keyoti Spell Checker is not found.");
            }
        }


        /// <summary>
        /// Creates custom user command "AppExit" and adds corresponding menu item to the standard menu.
        /// </summary>
        private void CreateAppExitCommand()
        {
            // Here we create command and get reference to it.
            Command cmdAppExit =
                docEditor.Commands.Add("AppExit",
                "E&xit",
                "Exits the demo application",
                new CommandHandler(CommandAppExit));

            // Now we get menu item for this command and add it to the help menu
            StandardMenuBar menu = docEditor.Bars.Menu as StandardMenuBar;
            menu.GetItemAt(0).MenuItems.Add(MenuItem.Separator);
            menu.GetItemAt(0).MenuItems.Add(cmdAppExit.GetMenuItem());
        }


        /// <summary>
        /// Creates customuser command "ReadOnly" and adds corresponding menu item to the standard menu.
        /// </summary>
        private void CreateReadOnlyCommand()
        {
            // Here we create command and get reference to it.
            Command cmdReadOnly =
                docEditor.Commands.Add("Read Only",
                         "Read Only",
                         "Switches read only mode on/off",
                         new CommandHandler(CommandReadOnly),
                         null,
                         new ConditionHandler(IsDocumentOpened),
                         new ConditionHandler(IsReadOnly));

            // Now we get menu item for this command and add it to the help menu
            StandardMenuBar menu = docEditor.Bars.Menu as StandardMenuBar;
            menu.GetItemAt(2).MenuItems.Add(MenuItem.Separator);
            menu.GetItemAt(2).MenuItems.Add(cmdReadOnly.GetMenuItem());
        }


        /// <summary>
        /// Conditional handler (Is Command Turned On) for read-only mode command.
        /// </summary>
        private bool IsReadOnly(EditorControl editor)
        {
            return (editor.Document != null) && editor.Options.IsReadOnly;
        }


        /// <summary>
        /// Conditional handler (Is Command Enabled) for read-only mode command.
        /// </summary>
        private bool IsDocumentOpened(EditorControl editor)
        {
            return (editor.Document != null);
        }


        /// <summary>
        /// Implements "ReadOnly" command.
        /// </summary>
        private void CommandReadOnly(EditorControl editor)
        {
            editor.Options.IsReadOnly = !editor.Options.IsReadOnly;
        }


        /// <summary>
        /// Implements "AppExit" command.
        /// </summary>
        private void CommandAppExit(EditorControl editor)
        {
            if(!CheckModified())
                return;

            Application.Exit();
        }


        /// <summary>
        /// If an exception occurs, we should show an error message box and let the application continue.
        /// <seealso cref="Application.ThreadException"/>.
        /// </summary>
        private void Application_ThreadException(object sender, ThreadExceptionEventArgs e)
        {
            MessageBox.Show(e.Exception.Message, Application.ProductName,
                            MessageBoxButtons.OK, MessageBoxIcon.Error);
        }


        /// <summary>
        /// Called when the user attempts to close the main form.
        /// Performs the standard check before closing a modified document.
        /// </summary>
        private void MainForm_Closing(object sender, CancelEventArgs e)
        {
           e.Cancel = (!CheckModified());
        }


        /// <summary>
        /// Updates application form title.
        /// </summary>
        private void UpdateFormTitle()
        {
            Text = (IsDocumentOpen ? string.Format("{0} - {1}",
                Path.GetFileName(docEditor.Document.Name), Application.ProductName)
                    : Application.ProductName);
        }


        /// <summary>
        /// Checks if document has unsaved changes and asks the user if he wants to discard them.
        /// </summary>
        /// <returns><b>True</b> if there is no unsaved changes or user wants to discard them.</returns>
        private bool CheckModified()
        {
            // If there is no document or document is not modified, it is okay to carry on.
            if((docEditor.Document == null) || !docEditor.Document.IsModified)
                return true;

            DialogResult dlgResult = MessageBox.Show(
                "Unsaved changes will be lost, do you want to proceed?",
                Application.ProductName,
                MessageBoxButtons.YesNo,
                MessageBoxIcon.Warning);

            switch(dlgResult)
            {
                case DialogResult.Yes:
                    // Signal to discard existing changes.
                    return true;
                case DialogResult.No:
                    // Signal to cancel the operation.
                    return false;
                default:
                    throw new ApplicationException("Unknown dialog result.");
            }
        }


        /// <summary>
        /// Returns <b>True</b> if there's an open document in the editor.
        /// </summary>
        private bool IsDocumentOpen
        {
            get { return (docEditor.Document != null); }
        }


        /// <summary>
        /// Handles application Idle event. This is used to update form title.
        /// <seealso cref="Application.Idle"/>.
        /// </summary>
        private void Application_Idle(object sender, EventArgs e)
        {
            UpdateFormTitle();
        }


        /// <summary>
        /// Name used for the newly created document.
        /// </summary>
        private const string NewDocumentFileName = "New Document";
        private IContainer components;

        private EditorControl docEditor;
    }
}