//////////////////////////////////////////////////////////////////////////
// Copyright 2005-2007 Aspose Pty Ltd. All Rights Reserved.
//
// This file is part of Aspose.Editor. The source code in this file
// is only intended as a supplement to the documentation, and is provided
// "as is", without warranty of any kind, either expressed or implied.
//////////////////////////////////////////////////////////////////////////

#if ASPOSE_EDITOR_DESKTOP
namespace Aspose.Editor.Desktop
#elif ASPOSE_EDITOR_CLIENT
namespace Aspose.Editor.Client
#endif
{
    /// <summary>
    /// Provides integration of the KeyotiRapidSpell for .NET with Aspose.Editor control.
    /// </summary>
    /// <example>
    /// In order to enable spell checking functionality in the Aspose.Editor it is required
    /// to add single line of code right after the Aspose.Editor instance is created.
    /// <code>
    /// // Editor conrol instance is created.
    /// mEditor = new EditorControl();
    /// // Adapter is installed. The line below is the only line required. Make sure this is not called twice.
    /// KeyotiRapidSpellAdapter.Install(mEditor);
    /// </code>
    /// </example>
    public class KeyotiRapidSpellAdapter
    {
        /// <summary>
        /// Installs the adapter within the specified editor control. This method shall be called once
        /// for each editor control. After this method is called changing <see cref="IsInstallSpellAsYouType"/>
        /// and <see cref="IsInstallSpellDialog"/> properties doesn't affect the installed adapter.
        /// </summary>
        /// <remarks>If this method is called multiple times for the same control then results are
        /// unpredictable.</remarks>
        public static void Install(EditorControl editorControl)
        {
            // Here we create instance of the adapter. It will create commands in the editor and thus
            // until editor is released adapter stays alive. We dont have to keep reference onto adapter.
            new KeyotiRapidSpellAdapterImpl(editorControl, IsInstallSpellDialog,
                IsInstallSpellAsYouType, IsSpellAsYouTypeEnabledByDefault);
        }


        /// <summary>
        /// Gets or sets indication of whether spell dialog shall be installed.
        /// </summary>
        /// <remarks>This property must be set before <see cref="Install"/> is called.</remarks>
        public static bool IsInstallSpellDialog
        {
            get { return mIsInstallSpellDialog; }
            set { mIsInstallSpellDialog = value; }
        }


        /// <summary>
        /// Gets or sets indication of whether check spelling as you type feature shall be installed.
        /// </summary>
        /// <remarks>This property must be set before <see cref="Install"/> is called.</remarks>
        public static bool IsInstallSpellAsYouType
        {
            get { return mIsInstallSpellAsYouType; }
            set { mIsInstallSpellAsYouType = value; }
        }


        /// <summary>
        /// Gets or sets indication of whether check spelling as you type feature is
        /// enabled by default when editor is shown.
        /// </summary>
        /// <remarks>This property only specifies initial state of the feature, however
        /// user can enable and disable it at runtime.</remarks>
        public static bool IsSpellAsYouTypeEnabledByDefault
        {
            get { return mIsSpellAsYouTypeEnabledByDefault; }
            set { mIsSpellAsYouTypeEnabledByDefault = value; }
        }


        private static bool mIsInstallSpellAsYouType = true;

        private static bool mIsInstallSpellDialog = true;

        private static bool mIsSpellAsYouTypeEnabledByDefault = true;
    }
}